@@ -5,7 +5,7 @@
 import sys
 import click
 
-import aliascore as core
+from topalias import aliascore as core
 
 
 class AliasedGroup(click.Group):
@@ -17,20 +17,36 @@ class AliasedGroup(click.Group):
         return super().get_command(ctx, cmd_name)
 
 
-@click.group(cls=AliasedGroup, context_settings=dict(help_option_names=["-h", "--help"]), invoke_without_command=True)
+@click.group(
+    cls=AliasedGroup,
+    context_settings=dict(help_option_names=["-h", "--help"]),
+    invoke_without_command=True,
+)
 @click.pass_context
 def cli(ctx) -> int:
     """Entrypoint function, group command"""
     if ctx.invoked_subcommand is None:
-        click.echo(
-            "topalias - linux bash/zsh alias generator & history analytics https://github.com/CSRedRat/topalias",
-        )
-        if not core.find_aliases():
-            top_history()
-        else:
-            core.top_alias()
+        main()
     return 0
 
+
+@cli.command(
+    context_settings=dict(help_option_names=["-h", "--help"]),
+)
+def main() -> int:
+    """Print bash history file."""
+    click.echo(
+        "topalias - linux bash/zsh alias generator & history analytics https://github.com/CSRedRat/topalias",
+    )
+    top_history()  # TODO: DEBUG, uncomment if below
+    # if not core.find_aliases():
+    #     top_history()
+    # else:
+    #     core.top_alias()
+    #     top_history(min=2)
+    return 0
+
+
 @cli.command(name="history")
 @click.option("--min", default=1, help="Will print alias not less than this.")
 def top_history(min) -> int:  # args=None, @click.pass_context
@@ -40,6 +56,7 @@ def top_history(min) -> int:  # args=None, @click.pass_context
     )
     return 0
 
+
 ALIASES = {
     "h": top_history,
 }
